pub struct Project {
pub id: u16,
pub app_name: String,
pub workspace_name: String,
pub package_name: String,
pub version_code: u16,
pub version_name: String,
pub date_created: u64,
pub custom_icon: bool,
pub color_palette: ProjectColorPalette,
pub sketchware_version: u8,
}Fields
id: u16app_name: Stringworkspace_name: Stringpackage_name: Stringversion_code: u16version_name: Stringdate_created: u64custom_icon: boolcolor_palette: ProjectColorPalettesketchware_version: u8Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Project
impl<'de> Deserialize<'de> for Project
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Parsable for Project
impl Parsable for Project
type ParseError = Error
type ReconstructionError = Error
Sourcefn parse(project: &str) -> Result<Project, Self::ParseError>
fn parse(project: &str) -> Result<Project, Self::ParseError>
Parses a decrypted content of itself and returns an instance of itself wrapped around a
ResultSourcefn reconstruct(&self) -> Result<String, Self::ReconstructionError>
fn reconstruct(&self) -> Result<String, Self::ReconstructionError>
Reconstructs itself into a string form wrapped around a
Result
by default, if not implemented, this will panic (unimplemented!())impl Eq for Project
impl StructuralPartialEq for Project